Module downstream_mining

Module downstream_mining 

Structs

DownstreamMiningNode
1 to 1 connection with a downstream node that implement the mining (sub)protocol can be either a mining device or a downstream proxy. A downstream can only be linked with an upstream at a time. Support multi upstrems for downstream do no make much sense.

Enums

Channel
DownstreamMiningNodeStatus

Functions

listen_for_downstream_mining

Type Aliases

EitherFrame
Message
StdFrame